MarketplaceToHost = {
    "default": "ebay.com",
    "EBAY_US": "ebay.com",
    "EBAY_MOTORS_US": "ebay.com/motors",
    "EBAY_CA": "ebay.ca",
    "EBAY_GB": "ebay.co.uk",
    "EBAY_AU": "ebay.com.au",
    "EBAY_AT": "ebay.at",
    "EBAY_BE_FR": "befr.ebay.be",
    "EBAY_FR": "ebay.fr",
    "EBAY_DE": "ebay.de",
    "EBAY_IT": "ebay.it",
    "EBAY_BE_NL": "benl.ebay.be",
    "EBAY_NL": "ebay.nl",
    "EBAY_ES": "ebay.es",
    "EBAY_CH": "ebay.ch",
    "EBAY_TW": "ebay.com/tw",
    "EBAY_CZ": "ebay.com/sch/Czech-Republic",
    "EBAY_DK": "ebay.com/sch/Denmark",
    "EBAY_FI": "ebay.com/sch/Finland",
    "EBAY_GR": "ebay.com/sch/Greece",
    "EBAY_HK": "ebay.com.hk",
    "EBAY_HU": "ebay.com/sch/Hungary",
    "EBAY_IN": "ebay.in",
    "EBAY_ID": "id.ebay.com",
    "EBAY_IE": "ebay.ie",
    "EBAY_IL": "ebay.com/sch/Israel",
    "EBAY_MY": "ebay.com/my",
    "EBAY_NZ": "ebay.com/sch/New-Zealand",
    "EBAY_NO": "ebay.com/sch/Norway",
    "EBAY_PH": "ebay.ph",
    "EBAY_PL": "ebay.pl",
    "EBAY_PT": "ebay.com/sch/Portugal",
    "EBAY_PR": "ebay.com/sch/Puerto-Rico",
    "EBAY_RU": "ebay.com/sch/Russia",
    "EBAY_SG": "ebay.com/sg",
    "EBAY_ZA": "ebay.com/sch/South-Africa",
    "EBAY_SE": "ebay.com/sch/Sweden",
    "EBAY_TH": "export.ebay.co.th",
    "EBAY_VN": "ebay.vn",
    "EBAY_CN": "ebay.com/sch/China",
    "EBAY_PE": "ebay.com/sch/Peru",
    "EBAY_CA_FR": "cafr.ebay.ca",
    "EBAY_JP": "ebay.co.jp",
}
