# Generated by Django 4.1.5 on 2023-02-23 12:23

from django.db import migrations, models
import model_utils.fields
import uuid


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="AmocrmApp",
            fields=[
                (
                    "id",
                    model_utils.fields.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False),
                ),
                ("client_id", models.TextField(verbose_name="ID приложения")),
                ("client_secret", models.TextField(verbose_name="Секретный ключ приложения")),
                ("redirect_uri", models.TextField(verbose_name="Redirect URI приложения")),
                ("name", models.CharField(max_length=64, verbose_name="Локальный идентификатор")),
                ("access_token", models.TextField(null=True, verbose_name="Токен доступа")),
                ("access_token_expiry", models.DateTimeField(null=True, verbose_name="Дата истечения токена доступа")),
                ("refresh_token", models.TextField(null=True, verbose_name="Токен для обновления токена доступа")),
                (
                    "refresh_token_expiry",
                    models.DateTimeField(null=True, verbose_name="Дата истечения токена обновления"),
                ),
                ("is_default", models.BooleanField(default=False, verbose_name="Приложение по умолчанию")),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
